#
# spec file for package scout
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define cnfrepo zypp
Name:           scout
Version:        0.1.1+20180103.0595254
Release:        6.1
Summary:        Indexing Package Properties
License:        MIT
Group:          System/Packages
Url:            https://github.com/openSUSE/scout/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gettext
BuildRequires:  python
BuildRequires:  python-solv
BuildRequires:  python-xml
BuildRequires:  rpm-python
Requires:       python
Requires:       python-solv >= 0.6.0
Requires:       python-xml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The scout tool helps with indexing of various package properties.

%package -n command-not-found
Summary:        Command Not Found extension for shell
Group:          System/Packages
Requires:       python
Requires:       rpm-python
Requires:       scout = %{version}-%{release}

%description -n command-not-found
The "command not found" message is not very helpful. If e.g. the unzip
command is not found but it's available in a package, it would be very
interesting if the system could tell that the command is currently not
available, but installing a package would provide it.

%prep
%setup -q

%build
# compile scripts
python -mcompileall .

%install
# --- scout ---
# install python scripts
mkdir -p %{buildroot}%{python_sitelib}/%{name}
shopt -s extglob
cp -a scout/!(foo).py{,c} %{buildroot}%{python_sitelib}/%{name}
# install data files
install -D -m 0644 repos.conf %{buildroot}%{_datadir}/%{name}/repos.conf
# install scout binary
install -D -m 0755 scout-cmd.py %{buildroot}%{_bindir}/%{name}
# install bash completion
install -D -m 0644 scout-bash-completion %{buildroot}%{_sysconfdir}/bash_completion.d/scout.sh
# install manpage
install -D -m 0644 doc/scout.1 %{buildroot}%{_mandir}/man1/scout.1
# install and find languages
for po in i18n/scout/*.po; do
    pofile=${po##*/}
    lang=${pofile%.po}
    msgfmt $po -o i18n/scout/$lang.mo
    install -D -m 0644 i18n/scout/$lang.mo %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/scout.mo
done
%find_lang scout

# --- command-not-found ---
install -D -m 0755 handlers/bin/command-not-found %{buildroot}%{_bindir}/command-not-found
ln -sf command-not-found %{buildroot}%{_bindir}/cnf
# install manpage
install -D -m 0644 doc/command-not-found.1 %{buildroot}%{_mandir}/man1/command-not-found.1
ln -sf command-not-found.1.gz %{buildroot}%{_mandir}/man1/cnf.1.gz
# install shell handlers
for shell in bash zsh; do
    install -D -m 644 handlers/bin/command_not_found_${shell} %{buildroot}%{_sysconfdir}/${shell}_command_not_found
    sed -i 's:__REPO__:%{cnfrepo}:' %{buildroot}%{_sysconfdir}/${shell}_command_not_found
done
# install and find languages
for po in i18n/command-not-found/*.po; do
    pofile=${po##*/}
    lang=${pofile%.po}
    msgfmt $po -o i18n/command-not-found/$lang.mo
    install -D -m 0644 i18n/command-not-found/$lang.mo %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/command-not-found.mo
done
%find_lang command-not-found

%files -f scout.lang
%defattr(-,root,root)
%doc AUTHORS LICENSE README TODO doc/scout.html doc/scout.pdf
%{_bindir}/%{name}*
%{python_sitelib}/%{name}
%{_datadir}/%{name}
%config %{_sysconfdir}/bash_completion.d/*
%{_mandir}/man1/scout*

%files -n command-not-found -f command-not-found.lang
%defattr(-,root,root)
%doc handlers/bin/README
%{_bindir}/cnf
%{_bindir}/command-not-found
%config %{_sysconfdir}/*_command_not_found
%{_mandir}/man1/cnf*
%{_mandir}/man1/command-not-found*

%changelog
* Wed Jan  3 2018 opensuse-packaging@opensuse.org
- Update to version 0.1.1+20180103.0595254:
  * allow for multiple repos to be in one .repo file
  * Parse repo files for repo name (boo#980393)
  * Updated translations (Spanish, Norwegian Nynorsk)
* Fri Jun 30 2017 opensuse-packaging@opensuse.org
- Update to version 0.1.1+20170630.f55550e:
  * drop outdated DBs
* Thu Jun 29 2017 opensuse-packaging@opensuse.org
- Update to version 0.1.1+20170629.b80f023:
  * update translations using Weblate (Swedish, Chinese, French, Greek, Polish,
    Indonesian, Persian, Italian, Bulgarian, Lithuanian, Danish, Spanish)
  * zsh: avoid cnf being triggered on every false result
  * zsh: improve handler hooking
  * zsh: expect command to be quoted
  * zsh: define function with two names
  * detect if we have no repos configured (bsc#1037101)
  * call zypper refresh when solv file missing (bsc#1037101)
  * Version 0.1.1
* Mon May 30 2016 opensuse-packaging@opensuse.org
- Update to version 0.1.0+20160523.472154b:
  * Translated using Weblate (German)
  * Translated using Weblate (Lithuanian)
  * Translated using Weblate (Polish)
  * Translated using Weblate (Dutch)
  * Translated using Weblate (Norwegian Nynorsk)
  * Translated using Weblate (German)
  * Translated using Weblate (Arabic)
  * Translated using Weblate (French)
  * Translated using Weblate (Korean)
  * Translated using Weblate (Swedish)
* Mon May 30 2016 tchvatal@suse.com
- Cleanup a bit to have the spec readable and point to proper url
* Fri Oct 23 2015 dimstar@opensuse.org
- Update to version 0.1.0+20151023:
  + adapt to Dataiterator changes in libsolv-0.6.0 (boo#951977)
  + Updated translations.
* Fri Sep 25 2015 dimstar@opensuse.org
- Update to version 0.1.0+20150925:
  + Update translations based on https://svn.opensuse.org/svn/opensuse-i18n/trunk/lcn/ - REV 92845
    (boo#906691).
- Change to source service (disabled), checking out from git.
* Thu Apr 10 2014 mls@suse.de
- adapt to Dataiterator changes in libsolv-0.6.0
* Mon Mar  3 2014 mls@suse.de
- port from libsatsolver to libsolv [fate#316955]
- fix bnc#714558: support utf-8 chars in solvable names
* Thu Apr  5 2012 ke@suse.de
- scout.spec: minor cleanup.
* Wed Jun  2 2010 prusnak@opensuse.org
- update translations
* Wed Apr 28 2010 prusnak@suse.cz
- also check the file name, not only the package name while testing
  whether the package is installed
- add TEXTDOMAINDIR
- fix localization of one msg
* Mon Mar 15 2010 prusnak@suse.cz
- update repositories list
* Fri Sep 25 2009 prusnak@suse.cz
- added translations to scout:
    da es fi fr hu it ja km ko nl pl pt_BR ru uk zh_TW
- added translations to c-n-f:
    da es fi fr gl hu it ja km ko nl pl pt_BR ru uk wa zh_TW
* Wed Sep  9 2009 prusnak@suse.cz
- print message when inside midnight commander, don't just quit
* Tue Aug 18 2009 prusnak@suse.cz
- don't advise to use sudo when running as root
- fix manpages in packages
- fixed typos in cnf manpage
- escape the term before creating regexp
- suppress KeyboardInterrupt traceback after Ctrl+C
- refine text messages
- modify the search term before query
* Mon Mar 23 2009 prusnak@suse.cz
- command-not-found:
  * create cnf as symlink to command-not-found
  * print info line before the search
* Mon Feb  9 2009 prusnak@suse.cz
- scout:
  * fixed proper encoding of an error msg [bnc#460705]
  * added -p option (inverse search by package name)
  * don't exit successfully when nothing is found [bnc#466397]
  * always return EX_NOTFOUND [bnc#466397]
- command-not-found:
  * don't load all scout modules
  * more tests in bash handler (don't run in subshell or pipe)
  * check /usr/sbin and /sbin for binaries before using satsolver
  * require COMMAND_NOT_FOUND_AUTO to be set to run search directly
  * add documentation
* Tue Nov 18 2008 prusnak@suse.cz
- check number of unique packages in command-not-found
* Sat Nov  8 2008 prusnak@suse.cz
- don't write stacktraces when Ctrl+C is pressed
* Mon Nov  3 2008 prusnak@suse.cz
- modify zypp search to work with new python-satsolver
* Fri Oct 10 2008 prusnak@suse.cz
- print output of c-n-f to stderr
- remove no longer needed python-satsolver workarounds
- do not add zypp among repositories when python-satsolver not installed
- fix -r option
* Tue Sep 23 2008 prusnak@suse.cz
- do not run command-not-found handler inside Midnight Commander
* Fri Sep 19 2008 prusnak@suse.cz
- fixed bash completion and typo
* Fri Sep 12 2008 prusnak@suse.cz
- optimized zypp repository search
- fixed module instance creation in command-not-found
* Tue Sep  9 2008 prusnak@suse.cz
- added gettext support
* Mon Aug 18 2008 schwab@suse.de
- Fix name of completions file.
* Wed Aug  6 2008 prusnak@suse.cz
- updated to 0.1.0
  * enabled search in zypp repositories
* Thu Jun 12 2008 prusnak@suse.cz
- created package
